# powar
A dotfile/configuration manager unlike any other!

## Todo

|                                        | implement     | test     |
| :--------------------------------      | ------------: | -------: |
| custom paths                           | x             | x        |
| exec without files to install          | x             |          |
| jinja2                                 | x             |          |
| global/local variable merge            | x             |          |
| install in root paths with sudo        | x             |          |
| check for change in {powar,global}.yml | x             |          |
